@@ -1,11 +1,11 @@
 import os
 import sys
 from typing import List
-from anscenter.app.core.errors import PredictException, ModelLoadException
+from tqatest.app.core.errors import PredictException, ModelLoadException
 # from anscenter.app.core.config import MODEL_NAME, MODEL_PATH, MODEL_ID
 from loguru import logger
 # import ml.libs.annhub as annhub
-from anscenter.ml.libs import annhub
+from tqatest.ml.libs import annhub
 
 MODEL_NAME = "TrainedModel_c++.ann"
 MODEL_PATH = "ml/model"
